
.. image:: https://readthedocs.org/projects/pip/badge/?version=latest
   :target: https://ephemeris.readthedocs.org

.. image:: https://badge.fury.io/py/ephemeris.svg
   :target: https://pypi.python.org/pypi/ephemeris/

.. image:: https://travis-ci.org/galaxyproject/ephemeris.png?branch=master
   :target: https://travis-ci.org/galaxyproject/ephemeris

.. image:: https://coveralls.io/repos/galaxyproject/ephemeris/badge.svg?branch=master
   :target: https://coveralls.io/r/galaxyproject/ephemeris?branch=master

Ephemeris is a small Python library and set of scripts for managing the
bootstrapping of Galaxy_ plugins - tools, index data, and workflows.

* Free software: Academic Free License version 3.0
* Documentation: https://ephemeris.readthedocs.org.
* Code: https://github.com/galaxyproject/ephemeris


.. _Galaxy: http://galaxyproject.org/
.. _GitHub: https://github.com/
.. _Docker: https://www.docker.com/
.. _Homebrew: http://brew.sh/
.. _linuxbrew: https://github.com/Homebrew/linuxbrew
.. _Vagrant: https://www.vagrantup.com/
.. _Travis CI: http://travis-ci.org/
